@@ -1,6 +1,6 @@
 import time
 from pathlib import Path
-from subprocess import run
+from subprocess import PIPE, run
 
 from lamin_logger import logger
 
@@ -37,3 +37,19 @@ def setup_local_test_postgres(name: str = "pgtest"):
         raise RuntimeError("Failed to set up postgres test instance.")
     time.sleep(2)
     return f"postgresql://postgres:pwd@0.0.0.0:5432/{name}"
+
+
+def setup_local_test_postgres_supabase():
+    process = run(
+        f"""supabase start | grep 'anon key'|cut -f2 -d ":" | sed -e 's/^[[:space:]]*//'""",  # noqa
+        shell=True,
+        stdout=PIPE,
+    )
+    anon_key = process.stdout.decode("UTF-8").replace("\n", "")
+    open(".supabase_local_anon_key", "w").write(anon_key)
+    if process.returncode == 0:
+        logger.info("Created Supabase test instance.")
+    else:
+        raise RuntimeError("Failed to set up Supabase test instance.")
+    time.sleep(2)
+    return "postgresql://postgres:postgres@localhost:54322/postgres"
